@@ -11,10 +11,12 @@ OAuth settings ORKUT_CONSUMER_KEY and ORKUT_CONSUMER_SECRET are needed
 to enable this service support.
 """
 import urllib
+import logging
+logger = logging.getLogger(__name__)
 
-from django.conf import settings
 from django.utils import simplejson
 
+from social_auth.utils import setting
 from social_auth.backends import OAuthBackend, USERNAME
 from social_auth.backends.google import BaseGoogleOAuth
 
@@ -54,9 +56,9 @@ class OrkutAuth(BaseGoogleOAuth):
     def user_data(self, access_token):
         """Loads user data from Orkut service"""
         fields = ORKUT_DEFAULT_DATA
-        if hasattr(settings, 'ORKUT_EXTRA_DATA'):
-            fields += ',' + settings.ORKUT_EXTRA_DATA
-        scope = ORKUT_SCOPE + getattr(settings, 'ORKUT_EXTRA_SCOPE', [])
+        if setting('ORKUT_EXTRA_DATA'):
+            fields += ',' + setting('ORKUT_EXTRA_DATA')
+        scope = ORKUT_SCOPE + setting('ORKUT_EXTRA_SCOPE', [])
         params = {'method': 'people.get',
                   'id': 'myself',
                   'userId': '@me',
@@ -72,7 +74,7 @@ class OrkutAuth(BaseGoogleOAuth):
 
     def oauth_request(self, token, url, extra_params=None):
         extra_params = extra_params or {}
-        scope = ORKUT_SCOPE + getattr(settings, 'ORKUT_EXTRA_SCOPE', [])
+        scope = ORKUT_SCOPE + setting('ORKUT_EXTRA_SCOPE', [])
         extra_params['scope'] = ' '.join(scope)
         return super(OrkutAuth, self).oauth_request(token, url, extra_params)
 
