@@ -14,20 +14,19 @@ field, check OAuthBackend class for details on how to extend it.
 import logging
 logger = logging.getLogger(__name__)
 
+
 import cgi
 from urllib import urlencode
 from urllib2 import urlopen
 
-from django.conf import settings
 from django.utils import simplejson
 from django.contrib.auth import authenticate
 
 from social_auth.backends import BaseOAuth2, OAuthBackend, USERNAME
-from social_auth.utils import sanitize_log_data
+from social_auth.utils import sanitize_log_data, setting
 
 
 # Facebook configuration
-EXPIRES_NAME = getattr(settings, 'SOCIAL_AUTH_EXPIRATION', 'expires')
 FACEBOOK_ME = 'https://graph.facebook.com/me?'
 
 
@@ -35,18 +34,20 @@ class FacebookBackend(OAuthBackend):
     """Facebook OAuth2 authentication backend"""
     name = 'facebook'
     # Default extra data to store
-    EXTRA_DATA = [('id', 'id'), ('expires', EXPIRES_NAME)]
+    EXTRA_DATA = [
+        ('id', 'id'),
+        ('expires', setting('SOCIAL_AUTH_EXPIRATION', 'expires'))
+    ]
 
     def get_user_details(self, response):
         """Return user details from Facebook account"""
-        return {USERNAME: response.get('username') or response['name'],
+        return {USERNAME: response.get('username'),
                 'email': response.get('email', ''),
                 'fullname': response['name'],
                 'first_name': response.get('first_name', ''),
                 'last_name': response.get('last_name', '')}
 
 
-
 class FacebookAuth(BaseOAuth2):
     """Facebook OAuth2 support"""
     AUTH_BACKEND = FacebookBackend
@@ -57,7 +58,7 @@ class FacebookAuth(BaseOAuth2):
     SETTINGS_SECRET_NAME = 'FACEBOOK_API_SECRET'
 
     def get_scope(self):
-        return getattr(settings, 'FACEBOOK_EXTENDED_PERMISSIONS', [])
+        return setting('FACEBOOK_EXTENDED_PERMISSIONS', [])
 
     def user_data(self, access_token):
         """Loads user data from service"""
@@ -70,18 +71,18 @@ class FacebookAuth(BaseOAuth2):
                          sanitize_log_data(access_token),
                          extra=dict(data=data))
         except ValueError:
-            params.update({'access_token': sanitize_log_data(access_token)})
+            extra = {'access_token': sanitize_log_data(access_token)}
             logger.error('Could not load user data from Facebook.',
-                         exc_info=True, extra=dict(data=params))
+                         exc_info=True, extra=extra)
         return data
 
     def auth_complete(self, *args, **kwargs):
         """Completes loging process, must return user instance"""
         if 'code' in self.data:
             url = 'https://graph.facebook.com/oauth/access_token?' + \
-                  urlencode({'client_id': settings.FACEBOOK_APP_ID,
+                  urlencode({'client_id': setting('FACEBOOK_APP_ID'),
                              'redirect_uri': self.redirect_uri,
-                             'client_secret': settings.FACEBOOK_API_SECRET,
+                             'client_secret': setting('FACEBOOK_API_SECRET'),
                              'code': self.data['code']})
             response = cgi.parse_qs(urlopen(url).read())
             access_token = response['access_token'][0]
@@ -104,8 +105,7 @@ class FacebookAuth(BaseOAuth2):
     @classmethod
     def enabled(cls):
         """Return backend enabled status by checking basic settings"""
-        return all(hasattr(settings, name) for name in ('FACEBOOK_APP_ID',
-                                                        'FACEBOOK_API_SECRET'))
+        return setting('FACEBOOK_APP_ID') and setting('FACEBOOK_API_SECRET')
 
 
 # Backend definition
