@@ -1,6 +1,8 @@
 import urlparse
 from collections import defaultdict
 
+from django.conf import settings
+
 
 def sanitize_log_data(secret, data=None, leave_characters=4):
     """
@@ -63,12 +65,12 @@ def group_backend_by_type(items, key=lambda x: x):
 
     # Beware of cyclical imports!
     from social_auth.backends import \
-        BACKENDS, OpenIdAuth, BaseOAuth, BaseOAuth2
+        get_backends, OpenIdAuth, BaseOAuth, BaseOAuth2
 
     result = defaultdict(list)
 
     for item in items:
-        backend = BACKENDS[key(item)]
+        backend = get_backends()[key(item)]
         if issubclass(backend, OpenIdAuth):
             result['openid'].append(item)
         elif issubclass(backend, BaseOAuth2):
@@ -78,6 +80,11 @@ def group_backend_by_type(items, key=lambda x: x):
     return dict(result)
 
 
+def setting(name, default=None):
+    """Return setting value for given name or default value."""
+    return getattr(settings, name, default)
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
